NonZeroScalar

Struct NonZeroScalar 

#[repr(transparent)]
pub struct NonZeroScalar<C>
where C: CurveArithmetic,
{ scalar: Scalar<C>, }
Non-zero scalar type.

This type ensures that its value is not zero, ala core::num::NonZero*. To do this, the generic S type must impl both Default and ConstantTimeEq, with the requirement that S::default() returns 0.

In the context of ECC, it’s useful for ensuring that scalar multiplication cannot result in the point at infinity.

Fields

scalar: Scalar<C>

Implementations

Source

impl<C> NonZeroScalar<C>
where C: CurveArithmetic,

pub fn new(scalar: Scalar<C>) -> CtOption<Self>

Create a NonZeroScalar from a scalar.

pub fn from_repr(repr: FieldBytes<C>) -> CtOption<Self>

Decode a NonZeroScalar from a big endian-serialized field element.

pub fn from_uint(uint: C::Uint) -> CtOption<Self>

Create a NonZeroScalar from a C::Uint.

pub fn cast_array_as_inner<const N: usize>( scalars: &[Self; N], ) -> &[Scalar<C>; N]

Transform array reference containing NonZeroScalars to an array reference to the inner scalar type.

pub fn cast_slice_as_inner(scalars: &[Self]) -> &[Scalar<C>]

Transform slice containing NonZeroScalars to a slice of the inner scalar type.

pub fn random<R: CryptoRng + ?Sized>(rng: &mut R) -> Self

👎Deprecated since 0.14.0: use the Generate trait instead

Deprecated: Generate a random NonZeroScalar.