#[repr(transparent)]pub struct NonZeroScalar<C>where
C: CurveArithmetic,{
scalar: Scalar<C>,
}Expand description
Non-zero scalar type.
This type ensures that its value is not zero, ala core::num::NonZero*.
To do this, the generic S type must impl both Default and
ConstantTimeEq, with the requirement that S::default() returns 0.
In the context of ECC, it’s useful for ensuring that scalar multiplication cannot result in the point at infinity.
Fields
scalar: Scalar<C>Implementations
Sourceimpl<C> NonZeroScalar<C>where
C: CurveArithmetic,
impl<C> NonZeroScalar<C>where
C: CurveArithmetic,
Sourcepub fn new(scalar: Scalar<C>) -> CtOption<Self>
pub fn new(scalar: Scalar<C>) -> CtOption<Self>
Create a NonZeroScalar from a scalar.
Sourcepub fn from_repr(repr: FieldBytes<C>) -> CtOption<Self>
pub fn from_repr(repr: FieldBytes<C>) -> CtOption<Self>
Decode a NonZeroScalar from a big endian-serialized field element.
Sourcepub fn from_uint(uint: C::Uint) -> CtOption<Self>
pub fn from_uint(uint: C::Uint) -> CtOption<Self>
Create a NonZeroScalar from a C::Uint.
Sourcepub fn cast_array_as_inner<const N: usize>(
scalars: &[Self; N],
) -> &[Scalar<C>; N]
pub fn cast_array_as_inner<const N: usize>( scalars: &[Self; N], ) -> &[Scalar<C>; N]
Transform array reference containing NonZeroScalars to an array reference to the inner
scalar type.
Sourcepub fn cast_slice_as_inner(scalars: &[Self]) -> &[Scalar<C>] ⓘ
pub fn cast_slice_as_inner(scalars: &[Self]) -> &[Scalar<C>] ⓘ
Transform slice containing NonZeroScalars to a slice of the inner scalar type.